@@ -23,18 +23,30 @@
    timg@rrv.net
 */
 
-
 #ifndef TCD_CDDB_H
 #define TCD_CDDB_H
 
-#include "linux-cdrom.h"
+#include <SDL/SDL.h>
 
-int 		tcd_readcddb(cd_struct* cd, const char *filename);
-int 		tcd_writecddb(cd_struct* cd, const char *filename);
-int 		cddb_sum(int n);
-unsigned long 	cddb_discid( cd_struct *cd );
-void tcd_call_cddb_slave(cd_struct *cd, const char *package, const char *version);
-void tcd_call_cddb_submit(cd_struct *cd, const char *category, const char *service);
-int calc_offset(int minute, int second, int frame);
+#include "tcd.h"
+
+/**
+ * Reads the disc and track information from a CDDB data base.
+ * Preconditions:
+ * - the expression CD_INDRIVE(cdrom->status) shall be true.
+ */
+extern int tcd_readdiscinfo(struct cd_info *cd, const SDL_CD *cdrom);
+
+/**
+ * Writes the disc and track information into a CDDB data base.
+ * Preconditions:
+ * - the expression CD_INDRIVE(cdrom->status) shall be true.
+ */
+extern int tcd_writediscinfo(struct cd_info *cd, const SDL_CD *cdrom);
+
+/**
+ * Clears the disc and track information.
+ */
+extern void tcd_cleardiscinfo(struct cd_info *cd);
 
 #endif /* TCD_CDDB_H */
